@@ -1,6 +1,6 @@
 package Bundle::InterchangeKitchenSink;
 
-$VERSION = '0.10';
+$VERSION = '0.11';
 
 1;
 
@@ -72,12 +72,6 @@ Tie::Watch
 
 Time::HiRes
 
-GD
-
-GD::Text::Align
-
-GD::Graph
-
 =head1 DESCRIPTION
 
 This bundle installs the prerequisites for Interchange as well as some
